Have recently seen build times increase dramatically (~30s to ~90s), with no 
obvious huge additions to the project, though some dependencies have been 
upgraded. One thing I noticed is that I'm getting a warning twice:

WARNING: get already refers to: cljs.core/get being replaced by: 
allgress.util.http/get at line 19 
file:/home/dave/.m2/repository/allgress/util/0.1.1/util-0.1.1.jar!/allgress/util/http.cljs
WARNING: get already refers to: cljs.core/get being replaced by: 
allgress.util.http/get at line 19 
/home/dave/allgress/manage-survey/target/cljsbuild-compiler-0/allgress/util/http.cljs

Tried with :optimizations :none and :whitespace. Is this expected, or is there 
maybe something in how I've packaged the dependencies which is causing 
double-compilation? Thanks.

-- 
Note that posts from new members are moderated - please be patient with your 
first post.
--- 
You received this message because you are subscribed to the Google Groups 
"ClojureScript" group.
To unsubscribe from this group and stop receiving emails from it, send an email 
to [email protected].
To post to this group, send email to [email protected].
Visit this group at http://groups.google.com/group/clojurescript.

Reply via email to